@@ -12,7 +12,7 @@
 #
 ##############################################################################
 """
-$Id: SquidTool.py 45934 2007-07-20 08:19:12Z newbery $
+$Id: SquidTool.py 64105 2008-05-02 01:21:32Z newbery $
 """
 
 import os, re, httplib, urlparse, urllib, sys
@@ -72,7 +72,7 @@ def joinUrlPath(url, url2):
             break
     path = '/'.join(parts_path + parts_path2)
     path = urllib.quote(path,'/:')
-    return urlparse.urlunparse((scheme, host, path, None, None, None))
+    return urlparse.urlunparse((scheme, host, path, params2, query2, frag2))
 
 skins_re = re.compile('portal_skins')
 
@@ -144,8 +144,10 @@ class SquidTool(UniqueObject, SimpleItem):
         st = getToolByName(object, 'portal_skins', None)
         if st is None:
             return paths
-        sn = st.getSkinNameFromRequest(
-            REQUEST=getattr(object, 'REQUEST', None))
+        sn = None
+        REQUEST=getattr(object, 'REQUEST', None)
+        if REQUEST is not None:
+            sn = st.getSkinNameFromRequest(REQUEST=REQUEST)
         if sn is None:
             sn = st.getDefaultSkin()
         sp = st.getSkinPath(sn)
