@@ -12,7 +12,7 @@
 #
 ##############################################################################
 """
-$Id: utils.py 38374 2007-02-26 14:27:57Z dreamcatcher $
+$Id: utils.py 64105 2008-05-02 01:21:32Z newbery $
 """
 
 import sys
@@ -232,7 +232,7 @@ class Producer(object):
         # incase the queue is empty, wake it up so the .stopping flag is seen
         for q in self.queues.values():
             try:
-                q.put(None)
+                q.put(None, block=False)
             except Queue.Full:
                 # no problem - self.stopping should be seen.
                 pass
@@ -309,9 +309,10 @@ class Producer(object):
             # hosting in squid
             path = url
 
+        purge_path = urlparse.urlunparse(('','', path, params, query, fragment))
         logger.debug('making %s request to %s for %s.' % (purge_type,
-                                                          host, path))
-        conn.putrequest(purge_type, path)
+                                                          host, purge_path))
+        conn.putrequest(purge_type, purge_path, skip_accept_encoding=True)
         conn.endheaders()
         resp = conn.getresponse()
 
