@@ -1,13 +1,11 @@
-# Make sure Install imports.
-from Products.CacheSetup.Extensions import Install as _Install
-del _Install
+import os.path
+__version__ = open(os.path.join(__path__[0], 'VERSION.txt')).read().strip()
 
 from AccessControl import allow_module
 from Products.Archetypes import public as atapi
 from Products.CMFCore import utils as cmfutils
 from Products.CMFCore.DirectoryView import registerDirectory
 from Products.CMFPlone.interfaces import IPloneSiteRoot
-from Products.GenericSetup import EXTENSION, profile_registry
 from content import *
 from content.cache_tool import CacheTool
 from content.caching_policy_manager import CSCachingPolicyManager
@@ -59,24 +57,11 @@ def initialize(context):
     permissions = initialize_permissions()
     allTypes = zip(content_types, constructors)
     for atype, constructor in allTypes:
-        kind = "%s: %s" % (config.PROJECT_NAME, atype.archetype_name)
         cmfutils.ContentInit(
-            kind,
+            atype.meta_type,
             content_types      = (atype,),
             permission         = permissions[atype.portal_type],
             extra_constructors = (constructor,),
             fti                = ftis,
             ).initialize(context)
     
-    # GS Profiles are broken right now
-    # We'll fix them in the next release
-    # 
-    #profile_registry.registerProfile(
-    #    name='default',
-    #    title='CacheFu',
-    #    description='Extension profile for CacheFu',
-    #    path='profiles/default',
-    #    product='CacheSetup',
-    #    profile_type=EXTENSION,
-    #    for_=IPloneSiteRoot)
-
