@@ -1,147 +1,201 @@
 """
-CacheSetup
-~~~~~~~~~~~~~~~~~~~~~~~~~~~
+BaseCacheRule is the base class for ContentCacheRule,
+PolicyHTTPCacheManagerCacheRule and TemplateCacheRule.
 
-$Id: $
+$Id: base_cache_rule.py 64217 2008-05-03 03:31:12Z newbery $
 """
 
 __authors__ = 'Geoff Davis <geoff@geoffdavis.net>'
 __docformat__ = 'restructuredtext'
 
 from urllib import quote
-from Acquisition import aq_inner
-from Products.CMFPlone.interfaces import IBrowserDefault
 
+from zope.interface import implements
+from zope.tales.tales import CompilerError
+
+from Acquisition import aq_inner
+from DateTime import DateTime
 from AccessControl import ClassSecurityInfo
 from AccessControl.User import nobody
-import DateTime
 from Products.PageTemplates.Expressions import getEngine, SecureModuleImporter
-from Products.PageTemplates.TALES import CompilerError
 from ZopeUndo.Prefix import Prefix
 
-from Products.Archetypes import public as atapi
-try:
-    from Products.CMFCore import permissions
-except ImportError:
-    from Products.CMFCore import CMFCorePermissions as permissions
+from Products.Archetypes.interfaces import IBaseContent
+from Products.Archetypes.atapi import BaseContent
+from Products.Archetypes.atapi import DisplayList
+from Products.Archetypes.atapi import registerType
+from Products.Archetypes.atapi import Schema
+
+from Products.Archetypes.atapi import IntegerField
+from Products.Archetypes.atapi import LinesField
+from Products.Archetypes.atapi import StringField
+
+from Products.Archetypes.atapi import IntegerWidget
+from Products.Archetypes.atapi import LinesWidget
+from Products.Archetypes.atapi import MultiSelectionWidget
+from Products.Archetypes.atapi import SelectionWidget
+from Products.Archetypes.atapi import StringWidget
+
 from Products.CMFCore import Expression
 from Products.CMFCore.utils import getToolByName
+from Products.CMFCore import permissions
+
+from Products.CMFPlone.interfaces import IBrowserDefault
 
 from Products.CacheSetup.utils import base_hasattr
-from Products.CacheSetup.config import CACHE_TOOL_ID, PAGE_CACHE_MANAGER_ID
+from Products.CacheSetup.config import *
 from Products.CacheSetup.interfaces import ICacheRule
 from nocatalog import NoCatalog
 
-header_set_schema = atapi.Schema((
-                       atapi.LinesField('cacheStop',
-                                        default=('portal_status_message','statusmessages'),
-                                        widget=atapi.LinesWidget(label='Cache Preventing Request Values',
-                                                                 description='Values in the request that prevent caching if present'),
-                                        write_permission = permissions.ManagePortal,
-                                        ),
-                       atapi.StringField('predicateExpression',
-                                         required=0,
-                                         edit_accessor='getPredicateExpression',
-                                         widget=atapi.StringWidget(label='Predicate',
-                                                                   description='A TALES expression for determining whether this rule applies.  Available variables = request, object, view (ID of the current template), member (None if anonymous).',
-                                                                   size=80),
-                                         write_permission = permissions.ManagePortal,
-                                         ),
-                       atapi.StringField('headerSetIdAnon',
-                                         default='cache-with-etag',
-                                         widget=atapi.SelectionWidget(label='Header Set for Anonymous Users',
-                                                                      description='Header set for anonymous users.'),
-                                         vocabulary='getHeaderSetVocabulary',
-                                         enforce_vocabulary = 1,
-                                         write_permission = permissions.ManagePortal,
-                                         ),
-                       atapi.StringField('headerSetIdAuth',
-                                         default='cache-with-etag',
-                                         widget=atapi.SelectionWidget(label='Header Set for Authenticated Users',
-                                                                      description='Header set for authenticated users.'),
-                                         vocabulary='getHeaderSetVocabulary',
-                                         enforce_vocabulary = 1,
-                                         write_permission = permissions.ManagePortal,
-                                         ),
+schema = BaseContent.schema.copy()
 
-                       atapi.StringField('headerSetIdExpression',
-                                         required=0,
-                                         edit_accessor='getHeaderSetIdExpression',
-                                         widget=atapi.StringWidget(label='Header Set Expression',
-                                                                   description='A TALES expression that returns the ID of the header set to be used.  Applied if the header set specified above is set to "Expression".  Available variables = request, object, view (ID of the current template), member (None if anonymous)',
-                                                                   size=80),
-                                         write_permission = permissions.ManagePortal,
-                                         ),
-                       atapi.StringField('lastModifiedExpression',
-                                         default='python:object.modified()',
-                                         edit_accessor='getLastModifiedExpression',
-                                         widget=atapi.StringWidget(label='Last-Modified Expression',
-                                                                   description='An expression used to obtain the last-modified time for the page.  Used in setting the Last-Modified header',
-                                                                   size=80),
-                                         write_permission = permissions.ManagePortal,
-                                         ),
-                       atapi.StringField('varyExpression',
-                                          required=0,
-                                          default='python: rule.portal_cache_settings.getVaryHeader()',
-                                          edit_accessor='getVaryExpression',
-                                          widget=atapi.StringWidget(label='Vary Expression',
-                                                                    description='A TALES expression that will be used to generate the Vary header.  Available values: request, object, view (the template ID), member (None if Anonymous)',
-                                                                    size=80),
-                                          write_permission = permissions.ManagePortal,
-                                          ),
-                       ))
-etag_schema = atapi.Schema((
-                       atapi.LinesField('etagComponents',
-                                         default=('member','skin','language','gzip','catalog_modified'),
-                                         widget=atapi.MultiSelectionWidget(label='ETag Components',
-                                                                           description='Items used to construct the ETag',
-                                                                           format='checkbox',),
-                                         multiValued=1,
-                                         vocabulary=atapi.DisplayList((('member','Current member\'s ID'),
-                                                                       ('roles','Current member\'s roles'),
-                                                                       ('permissions','Current member\'s permissions'),
-                                                                       ('skin','Current skin'),
-                                                                       ('language','Browser\'s preferred language'),
-                                                                       ('user_language','User\'s preferred language'),
-                                                                       ('gzip','Browser can receive gzipped content'),
-                                                                       ('last_modified','Context modification time'),
-                                                                       ('catalog_modified', 'Time of last catalog change'),
-                                                                       )),
-                                         enforce_vocabulary = 1,
-                                         write_permission = permissions.ManagePortal,
-                                        ),
-                       atapi.LinesField('etagRequestValues',
-                                         default=(),
-                                         widget=atapi.LinesWidget(label='ETag Request Values',
-                                                                  description='Request values used to construct the ETag'),
-                                         write_permission = permissions.ManagePortal,
-                                        ),
-                       atapi.IntegerField('etagTimeout',
-                                          required=0,
-                                          default=3600,
-                                          widget=atapi.IntegerWidget(label='ETag Timeout',
-                                                                     description='Maximum amount of time an ETag is valid (leave blank for forever)'),
-                                          write_permission = permissions.ManagePortal,
-                                          ),
-                       atapi.StringField('etagExpression',
-                                          required=0,
-                                          edit_accessor='getEtagExpression',
-                                          widget=atapi.StringWidget(label='ETag Expression',
-                                                                    description='A TALES expression that will be appended to the ETag generated with the above settings when "The expression below" is selected.  Available values: request, object, view (the template ID), member (None if Anonymous)',
-                                                                    size=80),
-                                          write_permission = permissions.ManagePortal,
-                                          ),
-             ))
+header_set_schema = Schema((
 
-class BaseCacheRule(NoCatalog):
+    LinesField(
+        'cacheStop',
+        default=('portal_status_message','statusmessages'),
+        write_permission = permissions.ManagePortal,
+        widget=LinesWidget(
+            label='Cache Preventing Request Values',
+            description='Values in the request that prevent caching if present')),
+
+    StringField(
+        'predicateExpression',
+        required=0,
+        edit_accessor='getPredicateExpression',
+        write_permission = permissions.ManagePortal,
+        widget=StringWidget(
+            label='Predicate',
+            size=80,
+            description='A TALES expression for determining whether this rule applies. '
+                        'Available variables = request, object, view (ID of the current '
+                        'template), member (None if anonymous).')),
+
+    StringField(
+        'headerSetIdAnon',
+        default='cache-with-etag',
+        vocabulary='getHeaderSetVocabulary',
+        enforce_vocabulary = 1,
+        write_permission = permissions.ManagePortal,
+        widget=SelectionWidget(
+            label='Header Set for Anonymous Users',
+            description='Header set for anonymous users.')),
+
+    StringField(
+        'headerSetIdAuth',
+        default='cache-with-etag',
+        vocabulary='getHeaderSetVocabulary',
+        enforce_vocabulary = 1,
+        write_permission = permissions.ManagePortal,
+        widget=SelectionWidget(
+            label='Header Set for Authenticated Users',
+            description='Header set for authenticated users.')),
+
+    StringField(
+        'headerSetIdExpression',
+        required=0,
+        edit_accessor='getHeaderSetIdExpression',
+        write_permission = permissions.ManagePortal,
+        widget=StringWidget(
+            label='Header Set Expression',
+            size=80,
+            description='A TALES expression that returns the ID of the header set '
+                        'to be used.  Applied if the header set specified above is '
+                        'set to "Expression".  Available variables = request, object, '
+                        'view (ID of the current template), member (None if anonymous)')),
+
+    StringField(
+        'lastModifiedExpression',
+        default='python:object.modified()',
+        edit_accessor='getLastModifiedExpression',
+        write_permission = permissions.ManagePortal,
+        widget=StringWidget(
+            label='Last-Modified Expression',
+            size=80,
+            description='An expression used to obtain the last-modified time for '
+                        'the page.  Used in setting the Last-Modified header')),
+
+    StringField(
+        'varyExpression',
+        required=0,
+        default='python: rule.portal_cache_settings.getVaryHeader()',
+        edit_accessor='getVaryExpression',
+        write_permission = permissions.ManagePortal,
+        widget=StringWidget(
+            label='Vary Expression',
+            size=80,
+            description='A TALES expression that will be used to generate the Vary '
+                        'header.  Available values: request, object, view '
+                        '(the template ID), member (None if Anonymous)')),
+    ))
+
+etag_schema = Schema((
+
+    LinesField(
+        'etagComponents',
+        default=('member','skin','language','gzip','catalog_modified'),
+        multiValued=1,
+        enforce_vocabulary = 1,
+        write_permission = permissions.ManagePortal,
+        vocabulary=DisplayList((
+            ('member','Current member\'s ID'),
+            ('roles','Current member\'s roles'),
+            ('permissions','Current member\'s permissions'),
+            ('skin','Current skin'),
+            ('language','Browser\'s preferred language'),
+            ('user_language','User\'s preferred language'),
+            ('gzip','Browser can receive gzipped content'),
+            ('last_modified','Context modification time'),
+            ('catalog_modified', 'Time of last catalog change'))),
+        widget=MultiSelectionWidget(
+            label='ETag Components',
+            format='checkbox',
+            description='Items used to construct the ETag')),
+
+    LinesField(
+        'etagRequestValues',
+        default=(),
+        write_permission = permissions.ManagePortal,
+        widget=LinesWidget(
+            label='ETag Request Values',
+            description='Request values used to construct the ETag')),
+
+    IntegerField(
+        'etagTimeout',
+        required=0,
+        default=3600,
+        write_permission = permissions.ManagePortal,
+        widget=IntegerWidget(
+            label='ETag Timeout',
+            description='Maximum amount of time an ETag is valid (leave blank for forever)')),
+
+    StringField(
+        'etagExpression',
+        required=0,
+        edit_accessor='getEtagExpression',
+        write_permission = permissions.ManagePortal,
+        widget=StringWidget(
+            label='ETag Expression',
+            size=80,
+            description='A TALES expression that will be appended to the ETag '
+                        'generated with the above settings when "The expression '
+                        'below" is selected.  Available values: request, object, '
+                        'view (the template ID), member (None if Anonymous)')),
+    ))
+
+class BaseCacheRule(NoCatalog, BaseContent):
     """
     """
+    __implements__ = ICacheRule, BaseContent.__implements__
+    implements(IBaseContent)
+
     security = ClassSecurityInfo()
+    archetype_name = 'Base Cache Rule'
+    portal_type = meta_type = 'BaseCacheRule'
+    schema = schema
     global_allow = 0
     _at_rename_after_creation = True
 
-    __implements__ = (ICacheRule,)
-
     def _validate_expression(self, expression):
         try:
             getEngine().compile(expression)
@@ -226,13 +280,13 @@ class BaseCacheRule(NoCatalog):
 
     def lastDate(self, *dates):
         if len(dates) == 0:
-            return self.portal_cache_settings.modified()
+            return self.portal_cache_settings.getChangeDate()
         dates = list(dates)
         timeout = self.getEtagTimeout()
         if timeout:
-            time = DateTime.DateTime()
+            time = DateTime()
             time = timeout * (int(time.timeTime()/timeout) - 1)
-            time = DateTime.DateTime(time)
+            time = DateTime(time)
             dates.append(time)
         dates.sort()
         return dates[-1]
@@ -245,8 +299,8 @@ class BaseCacheRule(NoCatalog):
         spec['description'] = Prefix(path)
         lastTransaction = self._p_jar.db().undoInfo(0, 1, spec)
         if len(lastTransaction) == 0:
-            return DateTime.DateTime(self.Control_Panel.process_start)
-        return DateTime.DateTime(lastTransaction[0]['time'])
+            return DateTime(self.Control_Panel.process_start)
+        return DateTime(lastTransaction[0]['time'])
 
     def getVaryExpression(self):
         expression = self.getField('varyExpression').get(self)
@@ -269,7 +323,7 @@ class BaseCacheRule(NoCatalog):
     def _getExpressionContext(self, request, object, view, member, keywords=(), time=None):
         """Construct an expression context for TALES expressions used in cache rules and header sets"""
         if time is None:
-            time = DateTime.DateTime()
+            time = DateTime()
         data = {'rule'     : self,
                 'request'  : request,
                 'object'   : object,
@@ -324,7 +378,7 @@ class BaseCacheRule(NoCatalog):
         vocabulary = [('expression', 'Use expression below')] + \
                      [(hs.getId(), hs.Title()) for hs in headers.objectValues()] + \
                      [('None', 'Rule does not apply')]
-        return atapi.DisplayList(tuple(vocabulary))
+        return DisplayList(tuple(vocabulary))
         
     def getObjectDefaultView(self, obj):
         """Get the id of an object's default view"""
@@ -431,7 +485,7 @@ class BaseCacheRule(NoCatalog):
         timeout = self.getEtagTimeout()
         if timeout:
             if time is None:
-                time = DateTime.DateTime()
+                time = DateTime()
             etag = self._addEtagComponent(etag, int(time.timeTime()/timeout))
         return etag
 
@@ -439,3 +493,10 @@ class BaseCacheRule(NoCatalog):
     def getRelativeUrlsToPurge(self, object, urls):
         return urls
 
+registerType(BaseCacheRule, PROJECT_NAME)
+
+__all__ = (
+    'header_set_schema',
+    'etag_schema',
+    'BaseCacheRule',
+)
