@@ -11,123 +11,159 @@ __docformat__ = 'restructuredtext'
 import sets
 import urlparse
 
-from Acquisition import aq_inner
 import zope.component
+from zope.interface import implements
+
+from Acquisition import aq_inner
 from AccessControl import ClassSecurityInfo
 from AccessControl.PermissionRole import rolesForPermissionOn
 from BTrees import Length
 from DateTime import DateTime
 from ZODB.POSException import ConflictError
-from Products.PageTemplates.Expressions import getEngine, SecureModuleImporter
+from Products.Transience import Transience
+
+from Products.CMFCore.utils import UniqueObject
+from Products.CMFCore.utils import getToolByName
+from Products.CMFCore import permissions
+from Products.CMFCore.utils import _checkPermission
+
+from Products.Archetypes.atapi import Schema
+from Products.Archetypes.atapi import BaseSchema
+from Products.Archetypes.atapi import DisplayList
+from Products.Archetypes.atapi import OrderedBaseFolder
+from Products.Archetypes.atapi import registerType
+
+from Products.Archetypes.atapi import BooleanField
+from Products.Archetypes.atapi import StringField
+from Products.Archetypes.atapi import LinesField
+
+from Products.Archetypes.atapi import BooleanWidget
+from Products.Archetypes.atapi import SelectionWidget
+from Products.Archetypes.atapi import LinesWidget
+from Products.Archetypes.atapi import StringWidget
 
-from Products.Archetypes import public as atapi
 from Products.Archetypes.debug import log_exc
-try:
-    from Products.CMFCore import permissions
-except ImportError:
-    from Products.CMFCore import CMFCorePermissions as permissions
-from Products.CMFCore.utils import UniqueObject, getToolByName
-from zope.interface import implements
-from Products.CMFPlone.utils import _createObjectByType
+
 from Products.CacheSetup.interfaces import ICacheTool
 from Products.CacheSetup.interfaces import IPurgeUrls
 from Products.CacheSetup.enabler import enableCacheFu
 from Products.CacheSetup import config
+from Products.CacheSetup import __version__
 from nocatalog import NoCatalog
 
-schema = atapi.BaseSchema.copy() + atapi.Schema((
-    atapi.BooleanField('enabled',
-                      default=0,
-                      widget=atapi.BooleanWidget(label='Enable CacheFu',
-                                              description='Uncheck to turn off CacheFu\'s caching behavior.  Note: Disabling CacheFu '
-                                                          'does not purge proxy or browser caches so stale content may still continue '
-                                                          'to be served out of those caches.'),
-                      write_permission = permissions.ManagePortal,
-                      ),
-    atapi.StringField('activePolicyId',
-                      default=config.DEFAULT_POLICY_ID,
-                      widget=atapi.SelectionWidget(label='Active Cache Policy',
-                                                   description='Please indicate which cache policy to use.',
-                                                   condition='python:len(object.getActivePolicyVocabulary()) > 1'),
-                      vocabulary='getActivePolicyVocabulary',
-                      write_permission = permissions.ManagePortal,
-                      ),
-    atapi.StringField('cacheConfig', # XXX: This field is no longer used, and kept here hidden only so that we can migrate away from it
-                      default='zserver',
-                      widget=atapi.SelectionWidget(label='Cache Configuration',
-                                                   description='Please indicate how your cache(s) are configured.',
-                                                   visible={'edit': 'invisible', 'view': 'invisible'}),
-                      vocabulary=atapi.DisplayList((('zserver','Zope only'), ('apache','Zope behind Apache'), \
-                                                    ('squid','Zope behind Squid'),('squid_behind_apache','Zope behind Squid behind Apache'))),
-                      write_permission = permissions.ManagePortal,
-                      ),
-    atapi.StringField('proxyPurgeConfig',
-                      required=1,
-                      default='no-purge',
-                      widget=atapi.SelectionWidget(label='Proxy Cache Purge Configuration',
-                                                   description='If you are using a caching proxy such as Squid or Varnish in front '
-                                                               'of Zope, CacheFu needs to be able to tell this proxy to purge its '
-                                                               'cache of certain pages. If Apache is in front of Squid/Varnish, then '
-                                                               'this depends on Apache\'s "virtual hosting" configuration. The most common '
-                                                               'Apache configuration generates VirtualHostMonster-style URLs with '
-                                                               'RewriteRules/ProxyPass. If you have a legacy CacheFu 1.0 Squid-Apache '
-                                                               'install or other custom Apache configuration, you may want to choose '
-                                                               'the "custom URLs" option and customize the rewritePurgeUrls.py script.'),
-                      vocabulary=atapi.DisplayList((('no-purge','No Purge (zope-only, or zope-behind-apache)'),
-                                                    ('no-rewrite','Simple Purge (squid/varnish in front)'),
-                                                    ('vhm-rewrite','Purge with VHM URLs (squid/varnish behind apache, VHM virtual hosting)'),
-                                                    ('custom-rewrite','Purge with custom URLs (squid/varnish behind apache, custom virtual hosting)'))),
-                      write_permission = permissions.ManagePortal,
-                      ),
-    atapi.LinesField('domains',
-                     edit_accessor='getDomains',
-                     widget=atapi.LinesWidget(label='Site Domains',
-                                              description='Enter a list of domains for your site.  This is not needed if you chose "No Purge" '
-                                                          'under the Proxy Cache Purge Configuration option above. '
-                                                          'If your site handles both http://www.mysite.com:80 and http://mysite.com:80, '
-                                                          'be sure to include both. Also include https versions of your domains if you use them. '
-                                                          'Be sure to include a port for each site.'),
-                     write_permission = permissions.ManagePortal,
-                     ),
-    atapi.LinesField('squidURLs',
-                     edit_accessor='getSquidURLs',
-                     widget=atapi.LinesWidget(label='Proxy Cache Domains',
-                                              description='Enter a list of domains for any purgeable proxy caches. This is not needed if '
-                                                          'you chose "No Purge" or "Simple Purge" under "Proxy Cache Purge Configuration" '
-                                                          'above. For example, if you are using Squid with Apache in front, there will '
-                                                          'commonly be a single squid instance at http://127.0.0.1:3128'),
-                     write_permission = permissions.ManagePortal,
-                     ),
-    atapi.StringField('gzip',
-                      default='accept-encoding',
-                      widget=atapi.SelectionWidget(label='Compression',
-                                                   description='Should Zope compress pages before serving them, and if so, what criteria '
-                                                               'should be used to determine whether pages should be gzipped? The most common '
-                                                               'settings are "Never" (no compression) or "Use Accept-Encoding header" '
-                                                               '(only compress content if the browser explicitly declared support for compression).',),
-                      vocabulary=atapi.DisplayList((('never','Never'),('always','Always'),('accept-encoding','Use Accept-Encoding header'),('accept-encoding+user-agent','Use Accept-Encoding and User-Agent headers'))),
-                      write_permission = permissions.ManagePortal,
-                     ),
-    atapi.StringField('varyHeader',
-                       default='Accept-Encoding, Accept-Language',
-                       widget=atapi.StringWidget(label='Vary Header',
-                                                 description='Value for the Vary header.  If you are using gzipping, you may need to include '
-                                                             '"Accept-Encoding" and possibly "User-Agent". If you are running a multi-lingual site, '
-                                                             'you will need "Accept-Language". Values should be separated by commas.',
-                                                 size=60),
-                       write_permission = permissions.ManagePortal,
-                     ),
+schema = BaseSchema.copy() + Schema((
+
+    BooleanField(
+        'enabled',
+        default=False,
+        write_permission = permissions.ManagePortal,
+        widget=BooleanWidget(
+            label='Enable CacheFu',
+            description='Uncheck to turn off CacheFu\'s caching behavior.  Note: Disabling CacheFu '
+                        'does not purge proxy or browser caches so stale content may still continue '
+                        'to be served out of those caches.')),
+
+    StringField(
+        'activePolicyId',
+        default=config.DEFAULT_POLICY_ID,
+        vocabulary='getActivePolicyVocabulary',
+        write_permission = permissions.ManagePortal,
+        widget=SelectionWidget(
+            label='Active Cache Policy',
+            description='Please indicate which cache policy to use.',
+            condition='python:len(object.getActivePolicyVocabulary()) > 1')),
+
+    # XXX: The cacheConfig field is no longer used, and kept here hidden only so that we can migrate away from it
+    StringField(  
+        'cacheConfig',
+        widget=SelectionWidget(
+            label='Cache Configuration',
+            visible={'edit': 'invisible', 'view': 'invisible'})), 
+
+    StringField(
+        'proxyPurgeConfig',
+        required=1,
+        default='no-purge',
+        write_permission = permissions.ManagePortal,
+        vocabulary=DisplayList((
+            ('no-purge','No Purge (zope-only, or zope-behind-apache)'),
+            ('no-rewrite','Simple Purge (squid/varnish in front)'),
+            ('vhm-rewrite','Purge with VHM URLs (squid/varnish behind apache, VHM virtual hosting)'),
+            ('custom-rewrite','Purge with custom URLs (squid/varnish behind apache, custom virtual hosting)'))),
+        widget=SelectionWidget(
+            label='Proxy Cache Purge Configuration',
+            description='If you are using a caching proxy such as Squid or Varnish in front '
+                        'of Zope, CacheFu needs to be able to tell this proxy to purge its '
+                        'cache of certain pages. If Apache is in front of Squid/Varnish, then '
+                        'this depends on Apache\'s "virtual hosting" configuration. The most common '
+                        'Apache configuration generates VirtualHostMonster-style URLs with '
+                        'RewriteRules/ProxyPass. If you have a legacy CacheFu 1.0 Squid-Apache '
+                        'install or other custom Apache configuration, you may want to choose '
+                        'the "custom URLs" option and customize the rewritePurgeUrls.py script.')),
+
+    LinesField(
+        'domains',
+        edit_accessor='getDomains',
+        write_permission = permissions.ManagePortal,
+        widget=LinesWidget(
+            label='Site Domains',
+            description='Enter a list of domains for your site.  This is not needed if you chose "No Purge" '
+                        'under the Proxy Cache Purge Configuration option above. '
+                        'If your site handles both http://www.mysite.com:80 and http://mysite.com:80, '
+                        'be sure to include both. Also include https versions of your domains if you use them. '
+                        'Be sure to include a port for each site.')),
+
+    LinesField(
+        'squidURLs',
+        edit_accessor='getSquidURLs',
+        write_permission = permissions.ManagePortal,
+        widget=LinesWidget(
+            label='Proxy Cache Domains',
+            description='Enter a list of domains for any purgeable proxy caches. This is not needed if '
+                        'you chose "No Purge" or "Simple Purge" under "Proxy Cache Purge Configuration" '
+                        'above. For example, if you are using Squid with Apache in front, there will '
+                        'commonly be a single squid instance at http://127.0.0.1:3128')),
+
+    StringField(
+        'gzip',
+        default='accept-encoding',
+        write_permission = permissions.ManagePortal,
+        vocabulary=DisplayList((
+            ('never','Never'),
+            ('always','Always'),
+            ('accept-encoding','Use Accept-Encoding header'),
+            ('accept-encoding+user-agent','Use Accept-Encoding and User-Agent headers'))),
+        widget=SelectionWidget(
+            label='Compression',
+            description='Should Zope compress pages before serving them, and if so, what criteria '
+                        'should be used to determine whether pages should be gzipped? The most common '
+                        'settings are "Never" (no compression) or "Use Accept-Encoding header" '
+                        '(only compress content if the browser explicitly declared support for compression).')),
+
+    StringField(
+        'varyHeader',
+        default='Accept-Encoding',
+        write_permission = permissions.ManagePortal,
+        widget=StringWidget(
+            label='Vary Header',
+            size=60,
+            description='Value for the Vary header.  If you are using gzipping, you may need to include '
+                        '"Accept-Encoding" and possibly "User-Agent". If you are running a multi-lingual site, '
+                        'you may also need "Accept-Language". Values should be separated by commas.')),
     ))
 
+schema['title'].default = config.TOOL_TITLE
 schema['title'].widget.visible = {'edit': 'invisible', 'view': 'invisible'}
+schema['id'].widget.visible = {'edit': 'invisible', 'view': 'invisible'}
 
-class CacheTool(NoCatalog, atapi.OrderedBaseFolder, UniqueObject):
+class CacheTool(NoCatalog, OrderedBaseFolder, UniqueObject):
     """
     """
 
     implements(ICacheTool)
     archetype_name = 'Cache Configuration Tool'
     portal_type = meta_type = 'CacheTool'
+    plone_tool = 1
     security = ClassSecurityInfo()
     schema = schema
     content_icon = 'cachesetup_tool_icon.gif'
@@ -135,6 +171,7 @@ class CacheTool(NoCatalog, atapi.OrderedBaseFolder, UniqueObject):
     allowed_content_types=('CachePolicy',)
     _catalog_count = None
     _permission_count = None
+    _change_date = None
 
     actions = (
         {'action':      'string:$object_url',
@@ -155,20 +192,16 @@ class CacheTool(NoCatalog, atapi.OrderedBaseFolder, UniqueObject):
     def initializeArchetype(self, **kwargs):
         # get values from other places before archetypes initializes them
         squid_urls = self._getSquidUrls()
-        atapi.OrderedBaseFolder.initializeArchetype(self, **kwargs)
+        OrderedBaseFolder.initializeArchetype(self, **kwargs)
         # don't stomp on squid urls
         self._setSquidUrls(squid_urls)
 
-    #def at_post_edit_script(self):
-    #    # tool should not appear in portal_catalog
-    #    self.unindexObject()
-
     def getActivePolicyVocabulary(self, display=None):
         active = self.getActivePolicyId()
         vocabulary = [(p.getId(), p.Title()) for p in self.objectValues() if p.portal_type=="CachePolicy"]
         if display:
             vocabulary = [('(active policy)', '(active policy)')] + vocabulary
-        return atapi.DisplayList(tuple(vocabulary))
+        return DisplayList(tuple(vocabulary))
 
     # if active is gone, find another
     def getActivePolicyId(self):
@@ -213,27 +246,39 @@ class CacheTool(NoCatalog, atapi.OrderedBaseFolder, UniqueObject):
                 response.redirect('%s/%s' % (policy.absolute_url(), camefrom))
         return ''
 
-    # Changing header-sets here is pointless with multiple policies.
-    # Also, the old 'cache-in-proxy-1-hour' works just fine in non-proxy
-    # configs if we turn on page cache and improve the Last-Modified
-    # header (but not in squid 2.5) 
-    # 
-    #def setCacheConfig(self, value):
-    #    old_value = self.getCacheConfig()
-    #    self.getField('cacheConfig').set(self, value)
-    #    if value != old_value:
-    #        # only update rule when value changes
-    #        rules = self.getRules()
-    #        rule = getattr(rules, 'plone-content-types', None)
-    #        if rule is not None:
-    #            if value in ['squid', 'squid_behind_apache']:
-    #                # update the rule if it has not been changed already
-    #                if rule.getHeaderSetIdAnon() == 'cache-in-memory':
-    #                    rule.setHeaderSetIdAnon('cache-in-proxy-1-hour')
-    #            elif value in ['zserver', 'apache']:
-    #                # update the rule if it has not been changed already
-    #                if rule.getHeaderSetIdAnon() == 'cache-in-proxy-1-hour':
-    #                    rule.setHeaderSetIdAnon('cache-in-memory')
+    def getEnabled(self, reset=False):
+        """Let's disable CacheFu if the file system version doesn't
+        match the installed version to make sure we don't kill the site
+        if the schemas have changed.
+        """
+        installed_version = getattr(self, '_v_installed_version', None)
+        if reset or installed_version is None:
+            # Let's look this up once and save as a transient value.
+            qi = getToolByName(self, 'portal_quickinstaller')
+            try:
+                installed_version = qi._getOb('CacheSetup').getInstalledVersion()
+            except AttributeError:
+                # This can happen if someone manually removes the
+                # entry from the quickinstaller so let's punt and
+                # return a marker value so we can warn the user.
+                installed_version = 'Installed Version Not Found'
+            self._v_installed_version = installed_version
+
+        if installed_version != __version__:
+            # CacheSetup hasn't migrated yet so let's disable it.
+            # If unauthorized, just return False.
+            # (FIX THIS: disabling CacheFu should be less intrusive)
+            if not _checkPermission(permissions.ManagePortal, self):
+                return False
+            field = self.getField('enabled')
+            if field is None:
+                self._updateSchema()
+            elif field.get(self) == True:
+                field.set(self, False)
+            if getToolByName(self, config.PAGE_CACHE_MANAGER_ID, None) is not None:
+                enableCacheFu(self, False)
+
+        return self.getField('enabled').get(self)
 
     def setEnabled(self, value):
         old_value = self.getEnabled()
@@ -329,6 +374,16 @@ class CacheTool(NoCatalog, atapi.OrderedBaseFolder, UniqueObject):
 
     # ##### Counters for use in ETag/cache key building #####
 
+    def updateChangeDate(self):
+        # change_date is a DateTime that we will update 
+        # every time we increment a counter
+        if self._change_date is None:
+            self._change_date = Transience.Increaser(DateTime())
+        self._change_date.set(DateTime())
+
+    def getChangeDate(self):
+        return self._change_date()
+
     def incrementCatalogCount(self):
         # catalog_count is a minimal counter object that we will increment 
         # every time an object is indexed/reindexed/unindexed -- we will
@@ -336,7 +391,7 @@ class CacheTool(NoCatalog, atapi.OrderedBaseFolder, UniqueObject):
         if self._catalog_count is None:
             self._catalog_count = Length.Length()
         self._catalog_count.change(1)
-        self.setModificationDate()
+        self.updateChangeDate()
 
     def getCatalogCount(self):
         return self._catalog_count()
@@ -348,7 +403,7 @@ class CacheTool(NoCatalog, atapi.OrderedBaseFolder, UniqueObject):
         if self._permission_count is None:
             self._permission_count = Length.Length()
         self._permission_count.change(1)
-        self.setModificationDate()
+        self.updateChangeDate()
 
     def getPermissionCount(self):
         if self._permission_count is None:
@@ -503,6 +558,8 @@ class CacheTool(NoCatalog, atapi.OrderedBaseFolder, UniqueObject):
         if REQUEST is None:
             REQUEST = self.REQUEST
         use_gzip = self.getGzip()
+        if not self.getEnabled():
+            use_gzip = 'never'
 
         force = 0
         if use_gzip == 'never':
@@ -534,6 +591,8 @@ class CacheTool(NoCatalog, atapi.OrderedBaseFolder, UniqueObject):
     security.declarePublic('getRuleAndHeaderSet')
     def getRuleAndHeaderSet(self, request, object, view, member):
         """Get the caching rule that applies here and the header set specified by the rule"""
+        if not self.getEnabled():
+            return (None, None)
         rules = self.getRules().objectValues()
         for rule in rules:
             try:
@@ -630,4 +689,4 @@ class CacheTool(NoCatalog, atapi.OrderedBaseFolder, UniqueObject):
         except:
             return False
         
-atapi.registerType(CacheTool, config.PROJECT_NAME)
+registerType(CacheTool, config.PROJECT_NAME)
