@@ -16,18 +16,17 @@
 $Id: CachingPolicyManager.py 40138 2005-11-15 17:47:37Z jens $
 """
 
-from Globals import package_home
 import os
+
+from Globals import package_home
 from AccessControl import ClassSecurityInfo
 from Globals import InitializeClass
-try:
-    from Products.CMFCore import permissions
-except ImportError:
-    from Products.CMFCore import CMFCorePermissions as permissions
-from Products.CMFCore.utils import getToolByName
 from Globals import DTMLFile
 
+from Products.CMFCore import permissions
+from Products.CMFCore.utils import getToolByName
 from Products.CMFCore.CachingPolicyManager import CachingPolicyManager as CMFCachingPolicyManager
+
 from Products.CacheSetup.config import CACHE_TOOL_ID
 
 class CSCachingPolicyManager( CMFCachingPolicyManager ):
