@@ -9,85 +9,104 @@ __authors__ = 'Geoff Davis <geoff@geoffdavis.net>'
 __docformat__ = 'restructuredtext'
 
 from AccessControl import ClassSecurityInfo
-from Products.Archetypes import public as atapi
-from Products.Archetypes.public import listTypes
-from Products.Archetypes.interfaces import IBaseObject
 
-try:
-    from Products.CMFCore import permissions
-except ImportError:
-    from Products.CMFCore import CMFCorePermissions as permissions
+from Products.Archetypes.interfaces import IBaseObject
+from Products.Archetypes.atapi import BaseContent
+from Products.Archetypes.atapi import DisplayList
+from Products.Archetypes.atapi import listTypes
+from Products.Archetypes.atapi import registerType
+from Products.Archetypes.atapi import Schema
+
+from Products.Archetypes.atapi import BooleanField
+from Products.Archetypes.atapi import LinesField
+from Products.Archetypes.atapi import StringField
+from Products.Archetypes.atapi import TextField
+
+from Products.Archetypes.atapi import BooleanWidget
+from Products.Archetypes.atapi import LinesWidget
+from Products.Archetypes.atapi import MultiSelectionWidget
+from Products.Archetypes.atapi import StringWidget
+from Products.Archetypes.atapi import TextAreaWidget
+
+from Products.CMFCore import permissions
 from Products.CMFCore import Expression
 from Products.CMFCore.utils import getToolByName
+
 from Products.CacheSetup.config import PROJECT_NAME
 from Products.CacheSetup.utils import base_hasattr
 import base_cache_rule as BaseCacheRule
 
-schema = atapi.BaseContent.schema.copy() + \
-         atapi.Schema(
-     (atapi.TextField('description',
-                required=0,
-                allowable_content_types = ('text/plain',),
-                default='A cache rule for CMF content types',
-                widget=atapi.TextAreaWidget(
-                    label='Description',
-                    description='Basic documentation for this cache rule',
-                    cols=60,
-                    rows=5,),
-                write_permission = permissions.ManagePortal,
-                ),
-     atapi.LinesField('contentTypes',
-                required=1,
-                default=(),
-                widget=atapi.MultiSelectionWidget(
-                    label='Content Types',
-                    description='Please indicate the content types to which this rule applies',
-                    size=10),
-                multiValued = 1,
-                vocabulary='getContentTypesVocabulary',
-                write_permission = permissions.ManagePortal,
-                ),
-     atapi.BooleanField('defaultView',
-                default=1,
-                widget=atapi.BooleanWidget(
-                    label='Default View',
-                    description='Should this rule apply to the default view of this content object? The "default view" is the '
-                                'template that is shown when the user navigates to a content object without appending a template '
-                                'or view id to the end of the URL.'),
-                write_permission = permissions.ManagePortal,
-                ),
-     atapi.LinesField('templates',
-                widget=atapi.LinesWidget(
-                    label='Templates',
-                    description='IDs for additional templates to which this rule should apply, one per line. If the template is ' 
-                                'a Zope 3-style view, enter its name without the @@ prefix. For example, to cache ' 
-                                'the @@types-controlpanel view (probably not a good idea), enter "types-controlpanel"'),
-                write_permission = permissions.ManagePortal,
-                ),
-     )) + \
-     BaseCacheRule.header_set_schema + \
-     BaseCacheRule.etag_schema + \
-     atapi.Schema((
-     atapi.StringField('purgeExpression',
-                required=0,
-                widget=atapi.StringWidget(
-                    label='Purge Expression',
-                    description='A TALES expression that generates a list of additional URLs to purge (URLs should be relative to the portal root) when an object is reindexed.  Available values: request, object.',
-                    size=80),
-                write_permission = permissions.ManagePortal,
-                ),
-        ))
+schema = BaseContent.schema.copy() + Schema((
+
+    TextField(
+        'description',
+        required=0,
+        allowable_content_types = ('text/plain',),
+        default='A cache rule for CMF content types',
+        write_permission = permissions.ManagePortal,
+        widget=TextAreaWidget(
+            label='Description',
+            cols=60,
+            rows=5,
+            description='Basic documentation for this cache rule')),
+
+    LinesField(
+        'contentTypes',
+        required=1,
+        default=(),
+        multiValued = 1,
+        vocabulary='getContentTypesVocabulary',
+        write_permission = permissions.ManagePortal,
+        widget=MultiSelectionWidget(
+            label='Content Types',
+            size=10,
+            description='Please indicate the content types to which this rule applies')),
+
+    BooleanField(
+        'defaultView',
+        default=1,
+        write_permission = permissions.ManagePortal,
+        widget=BooleanWidget(
+            label='Default View',
+            description='Should this rule apply to the default view of this content object? '
+                        'The "default view" is the template that is shown when the user '
+                        'navigates to a content object without appending a template '
+                        'or view id to the end of the URL.')),
+
+    LinesField(
+        'templates',
+        write_permission = permissions.ManagePortal,
+        widget=LinesWidget(
+            label='Templates',
+            description='IDs for additional templates to which this rule should apply, one '
+                        'per line. If the template is a Zope 3-style view, enter its name '
+                        'without the @@ prefix. For example, to cache the @@types-controlpanel '
+                        'view (probably not a good idea), enter "types-controlpanel"')),
+
+    )) + BaseCacheRule.header_set_schema + BaseCacheRule.etag_schema + Schema((
+
+    StringField(
+        'purgeExpression',
+        required=0,
+        write_permission = permissions.ManagePortal,
+        widget=StringWidget(
+            label='Purge Expression',
+            size=80,
+            description='A TALES expression that generates a list of additional URLs to purge '
+                        '(URLs should be relative to the portal root) when an object is reindexed. '
+                        ' Available values: request, object.')),
+    ))
 
 schema['id'].widget.ignore_visible_ids=True                       
 schema['id'].widget.description="Should not contain spaces, underscores or mixed case. An 'X-Caching-Rule-Id' header with this id will be added."
 
-class ContentCacheRule(BaseCacheRule.BaseCacheRule, atapi.BaseContent):
+class ContentCacheRule(BaseCacheRule.BaseCacheRule):
     """
     """
     security = ClassSecurityInfo()
     archetype_name = 'Content Cache Rule'
     portal_type = meta_type = 'ContentCacheRule'
-    __implements__ = (atapi.BaseContent.__implements__, BaseCacheRule.BaseCacheRule.__implements__)
+    __implements__ = BaseCacheRule.BaseCacheRule.__implements__
     schema = schema
     _at_rename_after_creation = True
 
@@ -249,6 +268,10 @@ class ContentCacheRule(BaseCacheRule.BaseCacheRule, atapi.BaseContent):
                     title = '%s (%s)' % (title, id)
             types_list.append((id, title))
         types_list.sort(lambda x, y: cmp(x[1], y[1]))
-        return atapi.DisplayList(tuple(types_list))
+        return DisplayList(tuple(types_list))
 
-atapi.registerType(ContentCacheRule, PROJECT_NAME)
+registerType(ContentCacheRule, PROJECT_NAME)
+
+__all__ = (
+    'ContentCacheRule',
+)
