@@ -7,20 +7,21 @@ __authors__ = 'Geoff Davis <geoff@geoffdavis.net>'
 __docformat__ = 'restructuredtext'
 
 from AccessControl import ClassSecurityInfo
-from Products.Archetypes import public as atapi
+
+from Products.CMFCore import permissions
+
+from Products.Archetypes.atapi import OrderedBaseFolder
+from Products.Archetypes.atapi import registerType
+
 from Products.CacheSetup.interfaces import ICacheToolFolder
 from Products.CacheSetup.config import PROJECT_NAME
 from nocatalog import NoCatalog
 
-try:
-    from Products.CMFCore import permissions
-except ImportError:
-    from Products.CMFCore import CMFCorePermissions as permissions
 
-class RuleFolder(NoCatalog, atapi.OrderedBaseFolder):
+class RuleFolder(NoCatalog, OrderedBaseFolder):
     """A container for rule objects"""
 
-    __implements__ = (atapi.OrderedBaseFolder.__implements__, ICacheToolFolder)
+    __implements__ = (OrderedBaseFolder.__implements__, ICacheToolFolder)
     
     security = ClassSecurityInfo()
     archetype_name = 'Rule Folder'
@@ -43,4 +44,4 @@ class RuleFolder(NoCatalog, atapi.OrderedBaseFolder):
         'edit' :        'cache_policy_item_config'
     }
 
-atapi.registerType(RuleFolder, PROJECT_NAME)
+registerType(RuleFolder, PROJECT_NAME)
