@@ -75,10 +75,7 @@ def PT_pt_render(self, source=0, extra_context={}):
 
     if not self._v_cooked:
         self._cook()
-    if PLONE25:
-        __traceback_supplement__ = (PageTemplateTracebackSupplement, self, self.pt_getContext())
-    else:
-        __traceback_supplement__ = (PageTemplateTracebackSupplement, self)
+    __traceback_supplement__ = (PageTemplateTracebackSupplement, self, self.pt_getContext())
 
     if self._v_errors:
         e = str(self._v_errors)
@@ -111,7 +108,7 @@ def PT_pt_render(self, source=0, extra_context={}):
     if PLONE25:
         output = self.StringIO()
     else:
-        output = StringIO()
+        output = StringIO(u'')
 
     c = self.pt_getContext()
     c.update(extra_context)
@@ -122,33 +119,37 @@ def PT_pt_render(self, source=0, extra_context={}):
                    output,
                    tal=not source, strictinsert=0)()
 
-    # clean up - XXX
-    # try to eliminate circular references - this may be overkill
-    if LazyWrapper is not None:
-        context._compiler = None
-        context.contexts = None
-        context.repeat_vars = None
-        if PLONE25:
-            items = context.global_vars.items()
-        else:
-            items = context.vars.items()
-        for k,v in items:
-            if isinstance(v, LazyWrapper):
-                v._expr = None
-                v._econtext = None
-                v._result = None
-        if PLONE25:
-            if context.vars:
-                while len(context.vars):
-                    context.vars._pop()
-            context.global_vars.clear()
-            context.global_vars = None
-            context.local_vars.clear()
-            context.local_vars = None
-        else:
-            context.vars.clear()
-        context.vars = None
-        context._scope_stack = None
+    # The following looks like it was left over from when we still did macro caching
+    # I'm commenting it out for now as I don't think we do lazy expressions in cachefu anymore
+    # 
+    ##clean up - XXX
+    ## try to eliminate circular references - this may be overkill
+    #if LazyWrapper is not None:
+    #    context._compiler = None
+    #    context.contexts = None
+    #    context.repeat_vars = None
+    #    if PLONE25:
+    #        items = context.global_vars.items()
+    #    else:
+    #        items = context.vars.items()
+    #    for k,v in items:
+    #        if isinstance(v, LazyWrapper):
+    #            v._expr = None
+    #            v._econtext = None
+    #            v._result = None
+    #    if PLONE25:
+    #        if context.vars:
+    #            while len(context.vars):
+    #                context.vars._pop()
+    #        context.global_vars.clear()
+    #        context.global_vars = None
+    #        context.local_vars.clear()
+    #        context.local_vars = None
+    #    else:
+    #        context.vars.clear()
+    #    context.vars = None
+    #    context._scope_stack = None
+
     result = output.getvalue()
     if not source:
         _setCacheHeaders(self, extra_context, rule, header_set, expr_context)
