@@ -2,178 +2,84 @@
 """
 header set implementation tests
 
-$Id: test_header_set.py 47373 2007-08-16 06:16:51Z newbery $
+$Id: test_header_set.py 64217 2008-05-03 03:31:12Z newbery $
 """
 
 from base import CacheFuTestCase
 
-from App.Common import rfc1123_date
-from Products.Archetypes.atapi import *
-from Products.Archetypes.interfaces.layer import ILayerContainer
-from Products.CMFCore.permissions import ManagePortal
+from AccessControl import Unauthorized
+from Interface.Verify import verifyObject
+from Products.Archetypes.interfaces.base import IBaseContent
 from Products.CMFCore.utils  import getToolByName
 from Products.CMFPlone.utils import _createObjectByType
 
 from Products.CacheSetup.config import *
+from Products.CacheSetup.content.nocatalog import NoCatalog
 
-class TestHeaderSetSchemaFields(CacheFuTestCase):
-    """
-    this test class is not pretty useful, as optilude said, but it's
-    better to have it as long as there is work on refactoring the beast
-    """
+class TestHeaderSet(CacheFuTestCase):
 
     def afterSetUp(self):
         _createObjectByType('HeaderSet', self.folder, 'hs')
         self.hs = getattr(self.folder, 'hs')
 
-    def test_description(self):
-        field = self.hs.getField('description')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'text')
-        self.failUnlessEqual(field.allowable_content_types, ('text/plain',))
-        self.failUnlessEqual(field.default, 'A set of HTTP headers to be assigned with a caching rule')
-        self.failUnless(isinstance(field.widget, TextAreaWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
+    def testIsNoCatalog(self):
+        self.failUnless(isinstance(self.hs, NoCatalog))
 
-    def test_pageCache(self):
-        field = self.hs.getField('pageCache')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'boolean')
-        self.failUnlessEqual(field.default, 0)
-        self.failUnless(isinstance(field.widget, BooleanWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
+    def testImplementsBaseContent(self):
+        iface = IBaseContent
+        self.failUnless(iface.isImplementedBy(self.hs))
+        self.failUnless(verifyObject(iface, self.hs))
 
-    def test_lastModified(self):
-        field = self.hs.getField('lastModified')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'string')
-        self.failUnlessEqual(field.default, 'yes')
-        vocabulary = field.vocabulary
-        self.failUnless(isinstance(vocabulary, DisplayList))
-        config = [i[0] for i in (('yes', 'Yes'), ('no', 'No'), ('delete', 'No, and delete any pre-existing header'))]
-        self.failUnlessEqual(tuple(vocabulary), tuple(config))
-        self.failUnless(isinstance(field.widget, SelectionWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
+    def testTypeInfo(self):
+        ti = self.hs.getTypeInfo()
+        self.failUnlessEqual(ti.Title(), 'Response Header Set')
+        self.failUnlessEqual(ti.getId(), 'HeaderSet')
+        self.failUnlessEqual(ti.Metatype(), 'HeaderSet')
+        self.failUnlessEqual(ti.globalAllow(), 0)
+        self.failUnlessEqual(ti.getMethodAliases(), {'(Default)': 'cache_policy_item_config',
+                                                      'view': 'cache_policy_item_config',
+                                                      'edit': 'cache_policy_item_config'})
 
-    def test_etag(self):
-        field = self.hs.getField('etag')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'boolean')
-        self.failUnlessEqual(field.default, 1)
-        self.failUnless(isinstance(field.widget, BooleanWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
+    def testActions(self):
+        # not pretty sure about this
+        actions = ('object/view',)
+        ttool = getToolByName(self.portal, 'portal_types')
+        hs = ttool['HeaderSet']
+        # actions have ManagePortal permission set
+        self.assertRaises(Unauthorized, hs.getActionInfo, actions)
+        self.setRoles(['Manager', 'Member'])
+        info = hs.getActionInfo(actions)
+        self.failUnless(info is not None)
+        self.failUnlessEqual(info['url'], '')
 
-    def test_vary(self):
-        field = self.hs.getField('vary')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'boolean')
-        self.failUnlessEqual(field.default, 1)
-        self.failUnless(isinstance(field.widget, BooleanWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
+class TestHeaderSetMethods(CacheFuTestCase):
 
-    def test_maxAge(self):
-        field = self.hs.getField('maxAge')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'integer')
-        self.failUnlessEqual(field.default, None)
-        self.failUnless(isinstance(field.widget, IntegerWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
+    def afterSetUp(self):
+        _createObjectByType('HeaderSet', self.folder, 'hs')
+        self.hs = getattr(self.folder, 'hs')
 
-    def test_sMaxAge(self):
-        field = self.hs.getField('sMaxAge')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'integer')
-        self.failUnlessEqual(field.default, None)
-        self.failUnless(isinstance(field.widget, IntegerWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
+    def _test_validate_expression(self):
+        self.fail('not yet implemented...')
 
-    def test_mustRevalidate(self):
-        field = self.hs.getField('mustRevalidate')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'boolean')
-        self.failUnlessEqual(field.default, 0)
-        self.failUnless(isinstance(field.widget, BooleanWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
+    def _test_getLastModifiedValue(self):
+        self.fail('not yet implemented...')
 
-    def test_proxyRevalidate(self):
-        field = self.hs.getField('proxyRevalidate')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'boolean')
-        self.failUnlessEqual(field.default, 0)
-        self.failUnless(isinstance(field.widget, BooleanWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
+    def _test_getVaryValue(self):
+        self.fail('not yet implemented...')
 
-    def test_noCache(self):
-        field = self.hs.getField('noCache')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'boolean')
-        self.failUnlessEqual(field.default, 0)
-        self.failUnless(isinstance(field.widget, BooleanWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
+    def _test_getPageCacheKey(self):
+        self.fail('not yet implemented...')
 
-    def test_noStore(self):
-        field = self.hs.getField('noStore')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'boolean')
-        self.failUnlessEqual(field.default, 0)
-        self.failUnless(isinstance(field.widget, BooleanWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
+    def _test_getEtagValue(self):
+        self.fail('not yet implemented...')
 
-    def test_public(self):
-        field = self.hs.getField('public')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'boolean')
-        self.failUnlessEqual(field.default, 0)
-        self.failUnless(isinstance(field.widget, BooleanWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
+    def _test_getEtagValue(self):
+        self.fail('not yet implemented...')
 
-    def test_private(self):
-        field = self.hs.getField('private')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'boolean')
-        self.failUnlessEqual(field.default, 0)
-        self.failUnless(isinstance(field.widget, BooleanWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
+    def _test_getHeaders(self):
+        self.fail('not yet implemented...')
 
-    def test_noTransform(self):
-        field = self.hs.getField('noTransform')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'boolean')
-        self.failUnlessEqual(field.default, 0)
-        self.failUnless(isinstance(field.widget, BooleanWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
-
-    def test_preCheck(self):
-        field = self.hs.getField('preCheck')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'integer')
-        self.failUnlessEqual(field.default, None)
-        self.failUnless(isinstance(field.widget, IntegerWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
-
-    def test_postCheck(self):
-        field = self.hs.getField('postCheck')
-        self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.type, 'integer')
-        self.failUnlessEqual(field.default, None)
-        self.failUnless(isinstance(field.widget, IntegerWidget))
-        #self.failUnlessEqual(field.read_permission, ManagePortal)
-        self.failUnlessEqual(field.write_permission, ManagePortal)
+from App.Common import rfc1123_date
 
 # util for making content in a container
 def makeContent(container, id, portal_type, title=None):
@@ -183,7 +89,7 @@ def makeContent(container, id, portal_type, title=None):
         o.setTitle(title)
     return o
 
-class TestHeaderSet(CacheFuTestCase):
+class TestHeaderSetOld(CacheFuTestCase):
     USER1 = 'user1'
     
     def afterSetUp(self):
@@ -351,27 +257,33 @@ class TestHeaderSet(CacheFuTestCase):
         d = self._parseHeaders(headers_to_add)
         self.failIf(d.has_key('Expires'))
 
-        # purgeable proxy, set s-maxage
-        #pcs.setCacheConfig('squid')
-        pcs.setProxyPurgeConfig('no-rewrite')
-        self.failUnless(pcs.hasPurgeableProxy())
-        h.setSMaxAge(30)
-        d = self._getCacheControl(h.getHeaders(expr_context))
-        self.assertEqual(d['s-maxage'], '30')
-        h.setSMaxAge(None)
-        d = self._getCacheControl(h.getHeaders(expr_context))
-        self.failIf(d.has_key('s-maxage'))
+        # We've removed the purgeable magic overides from
+        # the code so no need to test this anymore
+        # 
+        ## purgeable proxy, set s-maxage
+        ##pcs.setCacheConfig('squid')
+        #pcs.setProxyPurgeConfig('no-rewrite')
+        #self.failUnless(pcs.hasPurgeableProxy())
+        #h.setSMaxAge(30)
+        #d = self._getCacheControl(h.getHeaders(expr_context))
+        #self.assertEqual(d['s-maxage'], '30')
+        #h.setSMaxAge(None)
+        #d = self._getCacheControl(h.getHeaders(expr_context))
+        #self.failIf(d.has_key('s-maxage'))
 
-        # when no purgeable proxy, don't set s-maxage
-        #pcs.setCacheConfig('zserver')
-        pcs.setProxyPurgeConfig('no-purge')
-        self.failIf(pcs.hasPurgeableProxy())
-        h.setSMaxAge(30)
-        d = self._getCacheControl(h.getHeaders(expr_context))
-        self.failIf(d.has_key('s-maxage'))
-        h.setSMaxAge(None)
-        d = self._getCacheControl(h.getHeaders(expr_context))
-        self.failIf(d.has_key('s-maxage'))
+        # We've removed the purgeable magic overides from
+        # the code so no need to test this anymore
+        # 
+        ## when no purgeable proxy, don't set s-maxage
+        ##pcs.setCacheConfig('zserver')
+        #pcs.setProxyPurgeConfig('no-purge')
+        #self.failIf(pcs.hasPurgeableProxy())
+        #h.setSMaxAge(30)
+        #d = self._getCacheControl(h.getHeaders(expr_context))
+        #self.failIf(d.has_key('s-maxage'))
+        #h.setSMaxAge(None)
+        #d = self._getCacheControl(h.getHeaders(expr_context))
+        #self.failIf(d.has_key('s-maxage'))
 
         h.setNoCache(True)
         (headers_to_add, headers_to_remove) = h.getHeaders(expr_context)
@@ -417,25 +329,31 @@ class TestHeaderSet(CacheFuTestCase):
         d = self._getCacheControl(h.getHeaders(expr_context))
         self.failIf(d.has_key('must-revalidate'))
 
-        # purgeable proxy, set proxy-revalidate
-        #pcs.setCacheConfig('squid')
-        pcs.setProxyPurgeConfig('no-rewrite')
-        h.setProxyRevalidate(True)
-        d = self._getCacheControl(h.getHeaders(expr_context))
-        self.assertEqual(d['proxy-revalidate'], None)
-        h.setProxyRevalidate(False)
-        d = self._getCacheControl(h.getHeaders(expr_context))
-        self.failIf(d.has_key('proxy-revalidate'))
+        # We've removed the purgeable magic overides from
+        # the code so no need to test this anymore
+        # 
+        ## purgeable proxy, set proxy-revalidate
+        ##pcs.setCacheConfig('squid')
+        #pcs.setProxyPurgeConfig('no-rewrite')
+        #h.setProxyRevalidate(True)
+        #d = self._getCacheControl(h.getHeaders(expr_context))
+        #self.assertEqual(d['proxy-revalidate'], None)
+        #h.setProxyRevalidate(False)
+        #d = self._getCacheControl(h.getHeaders(expr_context))
+        #self.failIf(d.has_key('proxy-revalidate'))
 
-        # no purgeable proxy, don't set proxy-revalidate
-        #pcs.setCacheConfig('apache')
-        pcs.setProxyPurgeConfig('no-purge')
-        h.setProxyRevalidate(True)
-        d = self._getCacheControl(h.getHeaders(expr_context))
-        self.assertEqual(d.get('proxy-revalidate',None), None)
-        h.setProxyRevalidate(False)
-        d = self._getCacheControl(h.getHeaders(expr_context))
-        self.failIf(d.has_key('proxy-revalidate'))
+        # We've removed the purgeable magic overides from
+        # the code so no need to test this anymore
+        # 
+        ## no purgeable proxy, don't set proxy-revalidate
+        ##pcs.setCacheConfig('apache')
+        #pcs.setProxyPurgeConfig('no-purge')
+        #h.setProxyRevalidate(True)
+        #d = self._getCacheControl(h.getHeaders(expr_context))
+        #self.assertEqual(d.get('proxy-revalidate',None), None)
+        #h.setProxyRevalidate(False)
+        #d = self._getCacheControl(h.getHeaders(expr_context))
+        #self.failIf(d.has_key('proxy-revalidate'))
 
         h.setNoTransform(True)
         d = self._getCacheControl(h.getHeaders(expr_context))
@@ -469,10 +387,11 @@ class TestHeaderSet(CacheFuTestCase):
         d = self._parseHeaders(headers_to_add)
         self.assertEqual(d['X-Caching-Rule-Id'], rule.getId())
         self.assertEqual(d['X-Header-Set-Id'], h.getId())
-        
+
 def test_suite():
     from unittest import TestSuite, makeSuite
     suite = TestSuite()
-    suite.addTest(makeSuite(TestHeaderSetSchemaFields))
     suite.addTest(makeSuite(TestHeaderSet))
+    suite.addTest(makeSuite(TestHeaderSetMethods))
+    suite.addTest(makeSuite(TestHeaderSetOld))
     return suite
